@@ -15,8 +15,8 @@
 
 import ddt
 
-from zaqar.queues import bootstrap
-from zaqar.queues.storage import utils
+from zaqar import bootstrap
+from zaqar.storage import utils
 from zaqar import tests as testing
 
 
@@ -38,8 +38,8 @@ class TestUtils(testing.TestBase):
         self.assertTrue(utils.can_connect('redis://localhost'))
         self.assertTrue(utils.can_connect('redis://localhost:6379'))
 
-    def test_can_connect_suceeds_if_good_uri_sqlite(self):
-        self.assertTrue(utils.can_connect('sqlite://:memory:'))
+    # def test_can_connect_suceeds_if_good_uri_sqlite(self):
+    #    self.assertTrue(utils.can_connect('sqlite://:memory:'))
 
     def test_can_connect_fails_if_bad_uri_missing_schema(self):
         self.assertFalse(utils.can_connect('localhost:27017'))
@@ -47,10 +47,12 @@ class TestUtils(testing.TestBase):
     @testing.requires_mongodb
     def test_can_connect_fails_if_bad_uri_mongodb(self):
         self.config(unreliable=True)
-        self.assertFalse(utils.can_connect('mongodb://localhost:8080',
-                                           conf=self.conf))
-        self.assertFalse(utils.can_connect('mongodb://example.com:27017',
-                                           conf=self.conf))
+
+        uri = 'mongodb://localhost:8080?connectTimeoutMS=100'
+        self.assertFalse(utils.can_connect(uri, conf=self.conf))
+
+        uri = 'mongodb://example.com:27017?connectTimeoutMS=100'
+        self.assertFalse(utils.can_connect(uri, conf=self.conf))
 
     @testing.requires_redis
     def test_can_connect_fails_if_bad_uri_redis(self):
