@@ -31,10 +31,11 @@ them do, an AttributeError exception will be raised.
 
 import contextlib
 
-from oslo_log import log as logging
+import six
 
 from zaqar.common import decorators
 from zaqar.i18n import _
+import zaqar.openstack.common.log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -57,7 +58,7 @@ class Pipeline(object):
         for `method`.
 
         :params method: The method name to call on each stage
-        :type method: `str`
+        :type method: `six.text_type`
 
         :returns: A callable to consume the pipeline.
         """
@@ -74,7 +75,7 @@ class Pipeline(object):
             :param args: Positional arguments to pass to the call.
             :param kwargs: Keyword arguments to pass to the call.
 
-            :raises AttributeError: if none of the stages implement `method`
+            :raises: AttributeError if none of the stages implement `method`
             """
             # NOTE(flaper87): Used as a way to verify
             # the requested method exists in at least
@@ -87,10 +88,10 @@ class Pipeline(object):
                 try:
                     target = getattr(stage, method)
                 except AttributeError:
-                    sstage = str(stage)
+                    sstage = six.text_type(stage)
                     msgtmpl = _(u"Stage %(stage)s does not "
                                 "implement %(method)s")
-                    LOG.debug(msgtmpl, {'stage': sstage, 'method': method})
+                    LOG.warning(msgtmpl, {'stage': sstage, 'method': method})
                     continue
 
                 tmp = target(*args, **kwargs)
