@@ -19,13 +19,14 @@
 import abc
 import functools
 import time
+import uuid
 
 import enum
 from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import uuidutils
+import six
 
 from zaqar.common import decorators
+import zaqar.openstack.common.log as logging
 from zaqar.storage import errors
 from zaqar.storage import utils
 
@@ -34,7 +35,6 @@ DEFAULT_QUEUES_PER_PAGE = 10
 DEFAULT_MESSAGES_PER_PAGE = 10
 DEFAULT_POOLS_PER_PAGE = 10
 DEFAULT_SUBSCRIPTIONS_PER_PAGE = 10
-DEFAULT_TOPICS_PER_PAGE = 10
 
 DEFAULT_MESSAGES_PER_CLAIM = 10
 
@@ -51,14 +51,15 @@ class Capabilities(enum.IntEnum):
     HIGH_THROUGHPUT = 5
 
 
-class DriverBase(object, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class DriverBase(object):
     """Base class for both data and control plane drivers
 
     :param conf: Configuration containing options for this driver.
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `dogpile.cache.region.CacheRegion`
+    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
     """
     _DRIVER_OPTIONS = []
 
@@ -76,7 +77,8 @@ class DriverBase(object, metaclass=abc.ABCMeta):
                     pass
 
 
-class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class DataDriverBase(DriverBase):
     """Interface definition for storage drivers.
 
     Data plane storage drivers are responsible for implementing the
@@ -89,7 +91,7 @@ class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `dogpile.cache.region.CacheRegion`
+    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
     """
 
     BASE_CAPABILITIES = []
@@ -105,8 +107,7 @@ class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
         """Check whether the storage is ready."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def capabilities(self):
         """Returns storage's capabilities."""
         return self.BASE_CAPABILITIES
@@ -127,19 +128,14 @@ class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
         """Return the health status based on different backends."""
         raise NotImplementedError
 
-    @abc.abstractmethod
-    def close(self):
-        """Close connections to the backend."""
-        raise NotImplementedError
-
     def _get_operation_status(self):
         op_status = {}
         status_template = lambda s, t, r: {'succeeded': s,
                                            'seconds': t,
                                            'ref': r}
-        project = uuidutils.generate_uuid()
-        queue = uuidutils.generate_uuid()
-        client = uuidutils.generate_uuid()
+        project = str(uuid.uuid4())
+        queue = str(uuid.uuid4())
+        client = str(uuid.uuid4())
         msg_template = lambda s: {'ttl': 600, 'body': {'event': 'p_%s' % s}}
         messages = [msg_template(i) for i in range(100)]
         claim_metadata = {'ttl': 60, 'grace': 300}
@@ -153,10 +149,9 @@ class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
             try:
                 start = time.time()
                 result = callable_operation()
-            except Exception:
-                ref = uuidutils.generate_uuid()
-                LOG.exception('Error calling operation.',
-                              extra={'instance_uuid': ref})
+            except Exception as e:
+                ref = str(uuid.uuid4())
+                LOG.exception(e, extra={'instance_uuid': ref})
                 succeeded = False
             status = status_template(succeeded, time.time() - start, ref)
             op_status[operation_type] = status
@@ -227,31 +222,24 @@ class DataDriverBase(DriverBase, metaclass=abc.ABCMeta):
     def queue_controller(self):
         return self.control_driver.queue_controller
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def message_controller(self):
         """Returns the driver's message controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def claim_controller(self):
         """Returns the driver's claim controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def subscription_controller(self):
         """Returns the driver's subscription controller."""
         raise NotImplementedError
 
-    @decorators.lazy_property(write=False)
-    def topic_controller(self):
-        """Returns the driver's topic controller."""
-        return self.control_driver.topic_controller
 
-
-class ControlDriverBase(DriverBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class ControlDriverBase(DriverBase):
     """Interface definition for control plane storage drivers.
 
     Storage drivers that work at the control plane layer allow one to
@@ -265,44 +253,29 @@ class ControlDriverBase(DriverBase, metaclass=abc.ABCMeta):
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `dogpile.cache.region.CacheRegion`
+    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
     """
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def catalogue_controller(self):
         """Returns the driver's catalogue controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def pools_controller(self):
         """Returns storage's pool management controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def flavors_controller(self):
         """Returns storage's flavor management controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def queue_controller(self):
         """Returns the driver's queue controller."""
         raise NotImplementedError
 
-    @property
-    @abc.abstractmethod
-    def topic_controller(self):
-        """Returns the driver's topic controller."""
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    def close(self):
-        """Close connections to the backend."""
-        raise NotImplementedError
-
 
 class ControllerBase(object):
     """Top-level class for controllers.
@@ -315,7 +288,8 @@ class ControllerBase(object):
         self.driver = driver
 
 
-class Queue(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class Queue(ControllerBase):
     """This class is responsible for managing queues.
 
     Queue operations include CRUD, monitoring, etc.
@@ -325,21 +299,19 @@ class Queue(ControllerBase, metaclass=abc.ABCMeta):
     numbers of queues.
     """
 
-    def list(self, project=None, kfilter={}, marker=None,
-             limit=DEFAULT_QUEUES_PER_PAGE, detailed=False, name=None):
+    def list(self, project=None, marker=None,
+             limit=DEFAULT_QUEUES_PER_PAGE, detailed=False):
         """Base method for listing queues.
 
         :param project: Project id
-        :param kfilter: The key-value of metadata which user want to filter
         :param marker: The last queue name
         :param limit: (Default 10) Max number of queues to return
         :param detailed: Whether metadata is included
-        :param name: The queue name which user want to filter
 
         :returns: An iterator giving a sequence of queues
             and the marker of the next page.
         """
-        return self._list(project, kfilter, marker, limit, detailed, name)
+        return self._list(project, marker, limit, detailed)
 
     _list = abc.abstractmethod(lambda x: None)
 
@@ -350,7 +322,7 @@ class Queue(ControllerBase, metaclass=abc.ABCMeta):
         :param project: Project id
 
         :returns: Dictionary containing queue metadata
-        :raises DoesNotExist: if queue metadata does not exist
+        :raises: DoesNotExist
         """
         return self._get(name, project)
 
@@ -363,7 +335,7 @@ class Queue(ControllerBase, metaclass=abc.ABCMeta):
         :param project: Project id
 
         :returns: Dictionary containing queue metadata
-        :raises DoesNotExist: if queue metadata does not exist
+        :raises: DoesNotExist
         """
         raise NotImplementedError
 
@@ -373,7 +345,7 @@ class Queue(ControllerBase, metaclass=abc.ABCMeta):
         :param name: The queue name
         :param metadata: Queue metadata as a dict
         :param project: Project id
-        :raises DoesNotExist: if queue metadata can not be updated
+        :raises: DoesNotExist
         """
         raise NotImplementedError
 
@@ -423,25 +395,16 @@ class Queue(ControllerBase, metaclass=abc.ABCMeta):
 
     _stats = abc.abstractmethod(lambda x: None)
 
-    def calculate_resource_count(self, project=None):
-        """Base method for calculate queues amount.
 
-        :param project: Project id
-        :returns: The number of queues.
-        """
-        return self._calculate_resource_count(project)
-
-    _calculate_resource_count = abc.abstractmethod(lambda x: None)
-
-
-class Message(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class Message(ControllerBase):
     """This class is responsible for managing message CRUD."""
 
     @abc.abstractmethod
     def list(self, queue, project=None, marker=None,
              limit=DEFAULT_MESSAGES_PER_PAGE,
              echo=False, client_uuid=None,
-             include_claimed=False, include_delayed=False):
+             include_claimed=False):
         """Base method for listing messages.
 
         :param queue: Name of the queue to get the
@@ -455,8 +418,6 @@ class Message(ControllerBase, metaclass=abc.ABCMeta):
         :param client_uuid: A UUID object. Required when echo=False.
         :param include_claimed: omit claimed messages from listing?
         :type include_claimed: bool
-        :param include_delayed: omit delayed messages from listing
-        :type include_delayed: bool
 
         :returns: An iterator giving a sequence of messages and
             the marker of the next page.
@@ -487,7 +448,7 @@ class Message(ControllerBase, metaclass=abc.ABCMeta):
         :param message_id: Message ID
 
         :returns: Dictionary containing message data
-        :raises DoesNotExist: if message data can not be got
+        :raises: DoesNotExist
         """
         raise NotImplementedError
 
@@ -540,7 +501,7 @@ class Message(ControllerBase, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def bulk_delete(self, queue, message_ids, project=None, claim_ids=None):
+    def bulk_delete(self, queue, message_ids, project=None):
         """Base method for deleting multiple messages.
 
         :param queue: Name of the queue to post
@@ -548,7 +509,6 @@ class Message(ControllerBase, metaclass=abc.ABCMeta):
         :param message_ids: A sequence of message IDs
             to be deleted.
         :param project: Project id
-        :param claim_ids: claim IDs passed in by the delete request
         """
         raise NotImplementedError
 
@@ -564,7 +524,8 @@ class Message(ControllerBase, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
 
-class Claim(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class Claim(ControllerBase):
 
     @abc.abstractmethod
     def get(self, queue, claim_id, project=None):
@@ -576,7 +537,7 @@ class Claim(ControllerBase, metaclass=abc.ABCMeta):
         :param project: Project id
 
         :returns: (Claim's metadata, claimed messages)
-        :raises DoesNotExist: if claimed messages can not be got
+        :raises: DoesNotExist
         """
         raise NotImplementedError
 
@@ -622,7 +583,8 @@ class Claim(ControllerBase, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
 
-class Subscription(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class Subscription(ControllerBase):
     """This class is responsible for managing subscriptions of notification.
 
     """
@@ -633,11 +595,11 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Base method for listing subscriptions.
 
         :param queue: Name of the queue to get the subscriptions from.
-        :type queue: str
+        :type queue: six.text_type
         :param project: Project this subscription belongs to.
-        :type project: str
+        :type project: six.text_type
         :param marker: used to determine which subscription to start with
-        :type marker: str
+        :type marker: six.text_type
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :returns: An iterator giving a sequence of subscriptions
@@ -651,14 +613,14 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Returns a single subscription entry.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: str
+        :type queue: six.text_type
         :param subscription_id: ID of this subscription
-        :type subscription_id: str
+        :type subscription_id: six.text_type
         :param project: Project this subscription belongs to.
-        :type project: str
+        :type project: six.text_type
         :returns: Dictionary containing subscription data
         :rtype: {}
-        :raises SubscriptionDoesNotExist: if not found
+        :raises: SubscriptionDoesNotExist if not found
         """
         raise NotImplementedError
 
@@ -667,15 +629,15 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Create a new subscription.
 
         :param queue:The source queue for notifications
-        :type queue: str
+        :type queue: six.text_type
         :param subscriber: The subscriber URI
-        :type subscriber: str
+        :type subscriber: six.text_type
         :param ttl: time to live for this subscription
         :type ttl: int
         :param options: Options used to configure this subscription
         :type options: dict
         :param project: Project id
-        :type project: str
+        :type project: six.text_type
         :returns: True if a subscription was created and False
         if it is failed.
         :rtype: boolean
@@ -687,14 +649,12 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Updates the weight, uris, and/or options of this subscription
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: str
+        :type queue: six.text_type
         :param name: ID of the subscription
         :type name: text
         :param kwargs: one of: `source`, `subscriber`, `ttl`, `options`
         :type kwargs: dict
-        :raises SubscriptionDoesNotExist: if not found
-        :raises SubscriptionAlreadyExists: if attempt to update in a way to
-            create duplicate subscription
+        :raises: SubscriptionDoesNotExist if not found
         """
 
         raise NotImplementedError
@@ -704,11 +664,11 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Base method for testing subscription existence.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: str
+        :type queue: six.text_type
         :param subscription_id: ID of subscription
-        :type subscription_id: str
+        :type subscription_id: six.text_type
         :param project: Project id
-        :type project: str
+        :type project: six.text_type
         :returns: True if a subscription exists and False
             if it does not.
         """
@@ -719,52 +679,22 @@ class Subscription(ControllerBase, metaclass=abc.ABCMeta):
         """Base method for deleting a subscription.
 
         :param queue: Name of the queue subscription belongs to.
-        :type queue: str
+        :type queue: six.text_type
         :param subscription_id: ID of the subscription to be deleted.
-        :type subscription_id: str
+        :type subscription_id: six.text_type
         :param project: Project id
-        :type project: str
-        """
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    def get_with_subscriber(self, queue, subscriber, project=None):
-        """Base method for get a subscription with the subscriber.
-
-        :param queue: Name of the queue subscription belongs to.
-        :type queue: str
-        :param subscriber: link of the subscription to be notified.
-        :type subscriber: str
-        :param project: Project id
-        :type project: str
-        :returns: Dictionary containing subscription data
-        :rtype: dict
-        """
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    def confirm(self, queue, subscription_id, project=None, confirmed=True):
-        """Base method for confirming a subscription.
-
-        :param queue: Name of the queue subscription belongs to.
-        :type queue: str
-        :param subscription_id: ID of the subscription to be deleted.
-        :type subscription_id: str
-        :param project: Project id
-        :type project: str
-        :param confirmed: Confirm a subscription or cancel the confirmation of
-            a subscription.
-        :type confirmed: boolean
+        :type project: six.text_type
         """
         raise NotImplementedError
 
 
-class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class PoolsBase(ControllerBase):
     """A controller for managing pools."""
 
-    def _check_capabilities(self, uri, flavor=None, name=None):
-        default_store = self.driver.conf.drivers.message_store
-        pool_caps = self.capabilities(flavor=flavor, name=name)
+    def _check_capabilities(self, uri, group=None, name=None):
+        default_store = self.driver.conf.drivers.storage
+        pool_caps = self.capabilities(group=group, name=name)
 
         if not pool_caps:
             return True
@@ -772,32 +702,30 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
         new_store = utils.load_storage_impl(uri,
                                             default_store=default_store)
 
-        # NOTE(flaper87): Since all pools in a pool flavor
+        # NOTE(flaper87): Since all pools in a pool group
         # are assumed to have the same capabilities, it's
         # fine to check against just 1
         return pool_caps == new_store.BASE_CAPABILITIES
 
-    def capabilities(self, flavor=None, name=None):
-        """Gets the set of capabilities for this flavor/name
+    def capabilities(self, group=None, name=None):
+        """Gets the set of capabilities for this group/name
 
-        :param flavor: The pool flavor to get capabilities for
-        :type flavor: str
+        :param group: The pool group to get capabilities for
+        :type group: six.text_type
         :param name: The pool name to get capabilities for
-        :type name: str
+        :type name: six.text_type
         """
-        pllt = []
         if name:
-            pool = self.get(name)
-            pllt.append(pool)
+            group = list(self._get_group(self._get(name)['group']))
         else:
-            pllt = list(self._get_pools_by_flavor(flavor))
+            group = list(self._get_group(group))
 
-        if not len(pllt) > 0:
+        if not len(group) > 0:
             return ()
 
-        default_store = self.driver.conf.drivers.message_store
+        default_store = self.driver.conf.drivers.storage
 
-        pool_store = utils.load_storage_impl(pllt[0]['uri'],
+        pool_store = utils.load_storage_impl(group[0]['uri'],
                                              default_store=default_store)
 
         return pool_store.BASE_CAPABILITIES
@@ -807,7 +735,7 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Lists all registered pools.
 
         :param marker: used to determine which pool to start with
-        :type marker: str
+        :type marker: six.text_type
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :param detailed: whether to include options
@@ -820,57 +748,54 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
 
     _list = abc.abstractmethod(lambda x: None)
 
-    def create(self, name, weight, uri, flavor=None, options=None):
+    def create(self, name, weight, uri, group=None, options=None):
         """Registers a pool entry.
 
         :param name: The name of this pool
-        :type name: str
+        :type name: six.text_type
         :param weight: the likelihood that this pool will be used
         :type weight: int
         :param uri: A URI that can be used by a storage client
             (e.g., pymongo) to access this pool.
-        :type uri: str
-        :param flavor: The flavor of this pool
-        :type flavor: str
+        :type uri: six.text_type
+        :param group: The group of this pool
+        :type group: six.text_type
         :param options: Options used to configure this pool
         :type options: dict
         """
-        flavor_obj = {}
-        if flavor is not None:
-            flavor_obj["name"] = flavor
-        if not self._check_capabilities(uri, flavor=flavor_obj):
+        if not self._check_capabilities(uri, group=group):
             raise errors.PoolCapabilitiesMismatch()
 
-        return self._create(name, weight, uri, flavor, options)
+        return self._create(name, weight, uri, group, options)
 
     _create = abc.abstractmethod(lambda x: None)
 
-    def get_pools_by_flavor(self, flavor=None, detailed=False):
-        """Returns a pool list filtered by given pool flavor.
+    def get_group(self, group=None, detailed=False):
+        """Returns a single pool entry.
 
-        :param flavor: The flavor to filter on. `None` returns
-            pools that are not assigned to any pool flavor.
-        :type flavor: str
+        :param group: The group to filter on. `None` returns
+            pools that are not assigned to any pool.
+        :type group: six.text_type
         :param detailed: Should the options data be included?
         :type detailed: bool
         :returns: weight, uri, and options for this pool
         :rtype: {}
-        :raises PoolDoesNotExist: if not found
+        :raises: PoolDoesNotExist if not found
         """
-        return self._get_pools_by_flavor(flavor, detailed)
+        return self._get_group(group, detailed)
 
-    _get_pools_by_flavor = abc.abstractmethod(lambda x: None)
+    _get_group = abc.abstractmethod(lambda x: None)
 
     def get(self, name, detailed=False):
         """Returns a single pool entry.
 
         :param name: The name of this pool
-        :type name: str
+        :type name: six.text_type
         :param detailed: Should the options data be included?
         :type detailed: bool
         :returns: weight, uri, and options for this pool
         :rtype: {}
-        :raises PoolDoesNotExist: if not found
+        :raises: PoolDoesNotExist if not found
         """
         return self._get(name, detailed)
 
@@ -880,7 +805,7 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Returns a single pool entry.
 
         :param name: The name of this pool
-        :type name: str
+        :type name: six.text_type
         :returns: True if the pool exists
         :rtype: bool
         """
@@ -892,7 +817,7 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Removes a pool entry.
 
         :param name: The name of this pool
-        :type name: str
+        :type name: six.text_type
         :rtype: None
         """
         return self._delete(name)
@@ -906,7 +831,7 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
         :type name: text
         :param kwargs: one of: `uri`, `weight`, `options`
         :type kwargs: dict
-        :raises PoolDoesNotExist: if not found
+        :raises: PoolDoesNotExist
         """
         uri = kwargs.get('uri')
         if uri and not self._check_capabilities(uri, name=name):
@@ -923,7 +848,8 @@ class PoolsBase(ControllerBase, metaclass=abc.ABCMeta):
     _drop_all = abc.abstractmethod(lambda x: None)
 
 
-class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class CatalogueBase(ControllerBase):
     """A controller for managing the catalogue.
 
     The catalogue is responsible for maintaining a mapping
@@ -936,7 +862,7 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
 
         :param project: The project to use when filtering through queue
                         entries.
-        :type project: str
+        :type project: six.text_type
         :returns: [{'project': ..., 'queue': ..., 'pool': ...},]
         :rtype: [dict]
         """
@@ -948,12 +874,12 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         """Returns the pool identifier for the given queue.
 
         :param project: Namespace to search for the given queue
-        :type project: str
+        :type project: six.text_type
         :param queue: The name of the queue to search for
-        :type queue: str
+        :type queue: six.text_type
         :returns: {'pool': ...}
         :rtype: dict
-        :raises QueueNotMapped: if queue is not mapped
+        :raises: QueueNotMapped
         """
 
         raise NotImplementedError
@@ -963,9 +889,9 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         """Determines whether the given queue exists under project.
 
         :param project: Namespace to check.
-        :type project: str
+        :type project: six.text_type
         :param queue: str - Particular queue to check for
-        :type queue: str
+        :type queue: six.text_type
         :return: True if the queue exists under this project
         :rtype: bool
         """
@@ -975,11 +901,11 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         """Creates a new catalogue entry, or updates it if it already exists.
 
         :param project: str - Namespace to insert the given queue into
-        :type project: str
+        :type project: six.text_type
         :param queue: str - The name of the queue to insert
-        :type queue: str
+        :type queue: six.text_type
         :param pool: pool identifier to associate this queue with
-        :type pool: str
+        :type pool: six.text_type
         """
 
         raise NotImplementedError
@@ -989,9 +915,9 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         """Removes this entry from the catalogue.
 
         :param project: The namespace to search for this queue
-        :type project: str
+        :type project: six.text_type
         :param queue: The queue name to remove
-        :type queue: str
+        :type queue: six.text_type
         """
 
         raise NotImplementedError
@@ -1001,12 +927,12 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         """Updates the pool identifier for this queue.
 
         :param project: Namespace to search
-        :type project: str
+        :type project: six.text_type
         :param queue: The name of the queue
-        :type queue: str
+        :type queue: six.text_type
         :param pools: The name of the pool where this project/queue lives.
-        :type pools: str
-        :raises QueueNotMapped: if queue is not mapped
+        :type pools: six.text_type
+        :raises: QueueNotMapped
         """
 
         raise NotImplementedError
@@ -1018,7 +944,8 @@ class CatalogueBase(ControllerBase, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
 
-class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class FlavorsBase(ControllerBase):
     """A controller for managing flavors."""
 
     @abc.abstractmethod
@@ -1026,9 +953,9 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Lists all registered flavors.
 
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :param marker: used to determine which flavor to start with
-        :type marker: str
+        :type marker: six.text_type
         :param limit: (Default 10) Max number of results to return
         :type limit: int
         :returns: A list of flavors - name, project, flavor
@@ -1038,15 +965,15 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def create(self, name, project=None, capabilities=None):
+    def create(self, name, pool, project=None, capabilities=None):
         """Registers a flavor entry.
 
         :param name: The name of this flavor
-        :type name: str
+        :type name: six.text_type
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :param pool: The name of the pool to use for this flavor.
-        :type pool: str
+        :type pool: six.text_type
         :param capabilities: Flavor capabilities
         :type capabilities: dict
         """
@@ -1058,11 +985,11 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Returns a single flavor entry.
 
         :param name: The name of this flavor
-        :type name: str
+        :type name: six.text_type
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :rtype: {}
-        :raises FlavorDoesNotExist: if not found
+        :raises: FlavorDoesNotExist if not found
         """
 
         raise NotImplementedError
@@ -1072,9 +999,9 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Verifies whether the flavor exists.
 
         :param name: The name of this flavor
-        :type name: str
+        :type name: six.text_type
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :returns: True if the flavor exists
         :rtype: bool
         """
@@ -1086,9 +1013,9 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Removes a flavor entry.
 
         :param name: The name of this flavor
-        :type name: str
+        :type name: six.text_type
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :rtype: None
         """
 
@@ -1101,10 +1028,10 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         :param name: Name of the flavor
         :type name: text
         :param project: Project this flavor belongs to.
-        :type project: str
+        :type project: six.text_type
         :param kwargs: one of: `uri`, `weight`, `options`
         :type kwargs: dict
-        :raises FlavorDoesNotExist: if not found
+        :raises: FlavorDoesNotExist
         """
 
         raise NotImplementedError
@@ -1114,112 +1041,3 @@ class FlavorsBase(ControllerBase, metaclass=abc.ABCMeta):
         """Deletes all flavors from storage."""
 
         raise NotImplementedError
-
-
-class Topic(ControllerBase, metaclass=abc.ABCMeta):
-    """This class is responsible for managing topics.
-
-    Topic operations include CRUD, etc.
-
-    Storage driver implementations of this class should
-    be capable of handling high workloads and huge
-    numbers of topics.
-    """
-
-    def list(self, project=None, kfilter={}, marker=None,
-             limit=DEFAULT_TOPICS_PER_PAGE, detailed=False, name=None):
-        """Base method for listing topics.
-
-        :param project: Project id
-        :param kfilter: The key-value of metadata which user want to filter
-        :param marker: The last topic name
-        :param limit: (Default 10) Max number of topics to return
-        :param detailed: Whether metadata is included
-        :param name: The topic name which user want to filter
-
-        :returns: An iterator giving a sequence of topics
-            and the marker of the next page.
-        """
-        return self._list(project, kfilter, marker, limit, detailed, name)
-
-    _list = abc.abstractmethod(lambda x: None)
-
-    def get(self, name, project=None):
-        """Base method for topic metadata retrieval.
-
-        :param name: The topic name
-        :param project: Project id
-
-        :returns: Dictionary containing topic metadata
-        :raises DoesNotExist: if topic metadata does not exist
-        """
-        return self._get(name, project)
-
-    _get = abc.abstractmethod(lambda x: None)
-
-    def get_metadata(self, name, project=None):
-        """Base method for topic metadata retrieval.
-
-        :param name: The topic name
-        :param project: Project id
-
-        :returns: Dictionary containing topic metadata
-        :raises DoesNotExist: if topic metadata does not exist
-        """
-        raise NotImplementedError
-
-    def set_metadata(self, name, metadata, project=None):
-        """Base method for updating a topic metadata.
-
-        :param name: The topic name
-        :param metadata: Topic metadata as a dict
-        :param project: Project id
-        :raises DoesNotExist: if topic metadata can not be updated
-        """
-        raise NotImplementedError
-
-    def create(self, name, metadata=None, project=None):
-        """Base method for topic creation.
-
-        :param name: The topic name
-        :param project: Project id
-        :returns: True if a topic was created and False
-            if it was updated.
-        """
-        return self._create(name, metadata, project)
-
-    _create = abc.abstractmethod(lambda x: None)
-
-    def exists(self, name, project=None):
-        """Base method for testing topic existence.
-
-        :param name: The topic name
-        :param project: Project id
-        :returns: True if a topic exists and False
-            if it does not.
-        """
-        return self._exists(name, project)
-
-    _exists = abc.abstractmethod(lambda x: None)
-
-    def delete(self, name, project=None):
-        """Base method for deleting a topic.
-
-        :param name: The topic name
-        :param project: Project id
-        """
-        return self._delete(name, project)
-
-    _delete = abc.abstractmethod(lambda x: None)
-
-    def stats(self, name, project=None):
-        """Base method for topic stats.
-
-        :param name: The topic name
-        :param project: Project id
-        :returns: Dictionary with the
-            queue stats
-        """
-        return self._stats(name, project)
-
-    _stats = abc.abstractmethod(lambda x: None)
