@@ -11,33 +11,27 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-from oslo_log import log as logging
-from oslo_utils import netutils
-from osprofiler import profiler
 import redis
 import redis.sentinel
-import urllib
+from six.moves import urllib
 
 from zaqar.common import decorators
 from zaqar.common import errors
-from zaqar.conf import drivers_management_store_redis
-from zaqar.conf import drivers_message_store_redis
 from zaqar.i18n import _
+from zaqar.openstack.common import log as logging
 from zaqar import storage
 from zaqar.storage.redis import controllers
+from zaqar.storage.redis import options
 
+LOG = logging.getLogger(__name__)
 REDIS_DEFAULT_PORT = 6379
 SENTINEL_DEFAULT_PORT = 26379
 DEFAULT_SOCKET_TIMEOUT = 0.1
-DEFAULT_DBID = 0
 
 STRATEGY_TCP = 1
 STRATEGY_UNIX = 2
 STRATEGY_SENTINEL = 3
 
-LOG = logging.getLogger(__name__)
-
 
 class ConnectionURI(object):
     def __init__(self, uri):
@@ -50,19 +44,14 @@ class ConnectionURI(object):
         if parsed_url.scheme != 'redis':
             raise errors.ConfigurationError(_('Invalid scheme in Redis URI'))
 
+        # NOTE(kgriffs): Python 2.6 has a bug that causes the
+        # query string to be appended to the path when given a
+        # hostless URL.
         path = parsed_url.path
-        query = parsed_url.query
-        # NOTE(tkajinam): Replace '' by None
-        self.password = parsed_url.password or None
-        self.username = parsed_url.username or None
-
-        netloc = parsed_url.netloc
-        if '@' in netloc:
-            cred, sep, netloc = netloc.partition('@')
-
-        if self.username and not self.password:
-            raise errors.ConfigurationError(
-                _('Password should be set when username is set'))
+        if '?' in path:
+            path, sep, query = path.partition('?')
+        else:
+            query = parsed_url.query
 
         query_params = dict(urllib.parse.parse_qsl(query))
 
@@ -70,7 +59,6 @@ class ConnectionURI(object):
         self.strategy = None
         self.socket_timeout = float(query_params.get('socket_timeout',
                                                      DEFAULT_SOCKET_TIMEOUT))
-        self.dbid = int(query_params.get('dbid', DEFAULT_DBID))
 
         # TCP
         self.port = None
@@ -82,8 +70,6 @@ class ConnectionURI(object):
         # Sentinel
         self.master = None
         self.sentinels = []
-        self.sentinel_username = query_params.get('sentinel_username')
-        self.sentinel_password = query_params.get('sentinel_password')
 
         if 'master' in query_params:
             # NOTE(prashanthr_): Configure redis driver in sentinel mode
@@ -92,13 +78,19 @@ class ConnectionURI(object):
 
             # NOTE(kgriffs): Have to parse list of sentinel hosts ourselves
             # since urllib doesn't support it.
-            for each_host in netloc.split(','):
-                try:
-                    name, port = netutils.parse_host_port(
-                        each_host, SENTINEL_DEFAULT_PORT)
-                except ValueError:
-                    raise errors.ConfigurationError(
-                        'invalid redis server format %s' % each_host)
+            for each_host in parsed_url.netloc.split(','):
+                name, sep, port = each_host.partition(':')
+
+                if port:
+                    try:
+                        port = int(port)
+                    except ValueError:
+                        msg = _('The Redis configuration URI contains an '
+                                'invalid port')
+                        raise errors.ConfigurationError(msg)
+
+                else:
+                    port = SENTINEL_DEFAULT_PORT
 
                 self.sentinels.append((name, port))
 
@@ -107,8 +99,8 @@ class ConnectionURI(object):
                         'sentinel hosts')
                 raise errors.ConfigurationError(msg)
 
-        elif netloc:
-            if ',' in netloc:
+        elif parsed_url.netloc:
+            if ',' in parsed_url.netloc:
                 # NOTE(kgriffs): They probably were specifying
                 # a list of sentinel hostnames, but forgot to
                 # add 'master' to the query string.
@@ -155,14 +147,11 @@ class DataDriver(storage.DataDriverBase):
                          storage.Capabilities.AOD,
                          storage.Capabilities.HIGH_THROUGHPUT)
 
-    _DRIVER_OPTIONS = [(drivers_management_store_redis.GROUP_NAME,
-                        drivers_management_store_redis.ALL_OPTS),
-                       (drivers_message_store_redis.GROUP_NAME,
-                        drivers_message_store_redis.ALL_OPTS)]
+    _DRIVER_OPTIONS = options._config_options()
 
     def __init__(self, conf, cache, control_driver):
         super(DataDriver, self).__init__(conf, cache, control_driver)
-        self.redis_conf = self.conf[drivers_message_store_redis.GROUP_NAME]
+        self.redis_conf = self.conf[options.MESSAGE_REDIS_GROUP]
 
         server_version = self.connection.info()['redis_version']
         if tuple(map(int, server_version.split('.'))) < (2, 6):
@@ -184,9 +173,6 @@ class DataDriver(storage.DataDriverBase):
         except redis.exceptions.ConnectionError:
             return False
 
-    def close(self):
-        self.connection.close()
-
     def _health(self):
         KPI = {}
         KPI['storage_reachable'] = self.is_alive()
@@ -210,31 +196,15 @@ class DataDriver(storage.DataDriverBase):
 
     @decorators.lazy_property(write=False)
     def message_controller(self):
-        controller = controllers.MessageController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_message_store):
-            return profiler.trace_cls("redis_message_controller")(controller)
-        else:
-            return controller
+        return controllers.MessageController(self)
 
     @decorators.lazy_property(write=False)
     def claim_controller(self):
-        controller = controllers.ClaimController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_message_store):
-            return profiler.trace_cls("redis_claim_controller")(controller)
-        else:
-            return controller
+        return controllers.ClaimController(self)
 
     @decorators.lazy_property(write=False)
     def subscription_controller(self):
-        controller = controllers.SubscriptionController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_message_store):
-            return profiler.trace_cls("redis_subscription_"
-                                      "controller")(controller)
-        else:
-            return controller
+        return controllers.SubscriptionController(self)
 
 
 class ControlDriver(storage.ControlDriverBase):
@@ -242,14 +212,10 @@ class ControlDriver(storage.ControlDriverBase):
     def __init__(self, conf, cache):
         super(ControlDriver, self).__init__(conf, cache)
 
-        self.conf.register_opts(
-            drivers_management_store_redis.ALL_OPTS,
-            group=drivers_management_store_redis.GROUP_NAME)
+        self.conf.register_opts(options.MANAGEMENT_REDIS_OPTIONS,
+                                group=options.MANAGEMENT_REDIS_GROUP)
 
-        self.redis_conf = self.conf[drivers_management_store_redis.GROUP_NAME]
-
-    def close(self):
-        self.connection.close()
+        self.redis_conf = self.conf[options.MANAGEMENT_REDIS_GROUP]
 
     @decorators.lazy_property(write=False)
     def connection(self):
@@ -258,45 +224,19 @@ class ControlDriver(storage.ControlDriverBase):
 
     @decorators.lazy_property(write=False)
     def queue_controller(self):
-        controller = controllers.QueueController(self)
-        if (self.conf.profiler.enabled and
-                (self.conf.profiler.trace_message_store or
-                    self.conf.profiler.trace_management_store)):
-            return profiler.trace_cls("redis_queue_controller")(controller)
-        else:
-            return controller
+        return controllers.QueueController(self)
 
     @property
     def pools_controller(self):
-        controller = controllers.PoolsController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_management_store):
-            return profiler.trace_cls("redis_pools_controller")(controller)
-        else:
-            return controller
+        raise NotImplementedError()
 
     @property
     def catalogue_controller(self):
-        controller = controllers.CatalogueController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_management_store):
-            return profiler.trace_cls("redis_catalogue_"
-                                      "controller")(controller)
-        else:
-            return controller
+        raise NotImplementedError()
 
     @property
     def flavors_controller(self):
-        controller = controllers.FlavorsController(self)
-        if (self.conf.profiler.enabled and
-                self.conf.profiler.trace_management_store):
-            return profiler.trace_cls("redis_flavors_controller")(controller)
-        else:
-            return controller
-
-    @decorators.lazy_property(write=False)
-    def topic_controller(self):
-        pass
+        raise NotImplementedError()
 
 
 def _get_redis_client(driver):
@@ -306,29 +246,19 @@ def _get_redis_client(driver):
     if connection_uri.strategy == STRATEGY_SENTINEL:
         sentinel = redis.sentinel.Sentinel(
             connection_uri.sentinels,
-            db=connection_uri.dbid,
-            username=connection_uri.username,
-            password=connection_uri.password,
-            sentinel_kwargs={
-                'socket_timeout': connection_uri.socket_timeout,
-                'username': connection_uri.sentinel_username,
-                'password': connection_uri.sentinel_password
-            },
             socket_timeout=connection_uri.socket_timeout)
+
+        # NOTE(prashanthr_): The socket_timeout parameter being generic
+        # to all redis connections is inherited from the parameters for
+        # sentinel.
         return sentinel.master_for(connection_uri.master)
 
     elif connection_uri.strategy == STRATEGY_TCP:
-        return redis.Redis(
+        return redis.StrictRedis(
             host=connection_uri.hostname,
             port=connection_uri.port,
-            db=connection_uri.dbid,
-            username=connection_uri.username,
-            password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
     else:
-        return redis.Redis(
+        return redis.StrictRedis(
             unix_socket_path=connection_uri.unix_socket_path,
-            db=connection_uri.dbid,
-            username=connection_uri.username,
-            password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
