@@ -12,29 +12,29 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
+import uuid
 
 import falcon
 from oslo_serialization import jsonutils
-from oslo_utils import uuidutils
-from urllib import parse as urlparse
+import six.moves.urllib.parse as urlparse
 
 from zaqar.tests.unit.transport.wsgi import base
 
 
-class TestHomeDocument(base.V2Base):
+class TestHomeDocument(base.V1_1Base):
 
     config_file = 'wsgi_mongodb.conf'
 
     def test_json_response(self):
         self.headers = {
-            'Client-ID': uuidutils.generate_uuid(),
+            'Client-ID': str(uuid.uuid4()),
             'X-Project-ID': '8383830383abc_'
         }
-        body = self.simulate_get(self.url_prefix + '/', headers=self.headers)
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
+        body = self.simulate_get(self.url_prefix, headers=self.headers)
+        self.assertEqual(self.srmock.status, falcon.HTTP_200)
 
         content_type = self.srmock.headers_dict['Content-Type']
-        self.assertEqual('application/json-home', content_type)
+        self.assertEqual(content_type, 'application/json-home')
 
         try:
             jsonutils.loads(body[0])
@@ -43,11 +43,11 @@ class TestHomeDocument(base.V2Base):
 
     def test_href_template(self):
         self.headers = {
-            'Client-ID': uuidutils.generate_uuid(),
+            'Client-ID': str(uuid.uuid4()),
             'X-Project-ID': '8383830383'
         }
-        body = self.simulate_get(self.url_prefix + '/', headers=self.headers)
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
+        body = self.simulate_get(self.url_prefix, headers=self.headers)
+        self.assertEqual(self.srmock.status, falcon.HTTP_200)
         resp = jsonutils.loads(body[0])
         queue_href_template = resp['resources']['rel/queue']['href-template']
         path_1 = 'https://zaqar.example.com' + self.url_prefix
@@ -65,7 +65,7 @@ class TestHomeDocument(base.V2Base):
         url = urlparse.urljoin(path_1, queue_href_template)
         expected = ('https://zaqar.example.com' + self.url_prefix +
                     '/queues/foo')
-        self.assertEqual(expected, url.format(queue_name='foo'))
+        self.assertEqual(url.format(queue_name='foo'), expected)
 
         url = urlparse.urljoin(path_2, queue_href_template)
-        self.assertEqual(expected, url.format(queue_name='foo'))
+        self.assertEqual(url.format(queue_name='foo'), expected)
